@@ -4,7 +4,7 @@ algorithm with parameters.
 """
 
 import os
-from catboost import CatboostError, CatBoost
+from catboost import CatBoostError, CatBoost
 
 
 class FoldModel:
@@ -19,7 +19,7 @@ class FoldModel:
 
     def create_metrics_calcer(self, metrics, thread_count, eval_step=1):
         if not os.path.exists(self._model_path):
-            raise CatboostError("Model was deleted. Can't create calcer now")
+            raise CatBoostError("Model was deleted. Can't create calcer now")
         model = CatBoost()
         model.load_model(self._model_path)
         return model.create_metric_calcer(metrics, thread_count=thread_count, eval_period=eval_step)
